@@ -15,13 +15,18 @@ class Trocla
       private
 
       def charsets
-        @charsets ||= {
-          'default'       => chars,
-          'alphanumeric'  => alphanumeric,
-          'shellsafe'     => shellsafe,
-          'windowssafe'   => windowssafe,
-          'numeric'       => numeric,
-        }
+        @charsets ||= begin
+          h = {
+            'default'      => chars,
+            'alphanumeric' => alphanumeric,
+            'shellsafe'    => shellsafe,
+            'windowssafe'  => windowssafe,
+            'numeric'      => numeric,
+            'hexadecimal'  => hexadecimal,
+            'consolesafe'  => consolesafe,
+          }
+          h.each { |k, v| h[k] = v.uniq }
+        end
       end
 
       def chars
@@ -33,8 +38,14 @@ class Trocla
       def windowssafe
         @windowssafe ||= alphanumeric + windowssafe_chars
       end
+      def consolesafe
+        @consolesafe ||= alphanumeric + consolesafe_chars
+      end
+      def hexadecimal
+        @hexadecimal ||= numeric + ('a'..'f').to_a
+      end
       def alphanumeric
-        @alphanumeric ||= ('a'..'z').to_a + ('A'..'Z').to_a + ('0'..'9').to_a
+        @alphanumeric ||= ('a'..'z').to_a + ('A'..'Z').to_a + numeric
       end
       def numeric
         @numeric ||= ('0'..'9').to_a
@@ -48,6 +59,9 @@ class Trocla
       def windowssafe_chars
         @windowssafe_chars ||= "+%/@=?_.,".split(//)
       end
+      def consolesafe_chars
+        @consolesafe_chars ||= '+.-,_'.split(//)
+      end
     end
   end
 end
